/**
 * Copyright (C) 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package casino.ebean;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import models.casino.User;
import ninja.ebean.NinjaEbeanServerLifecycle;
import ninja.utils.LoggerProvider;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.slf4j.Logger;

import casino.CasinoUserManager;

import com.avaje.ebean.EbeanServer;
import com.google.inject.AbstractModule;
import com.google.inject.Guice;
import com.google.inject.Injector;

public class CasinoEbeanModuleTest {
    
    private Injector injector;
    
    private NinjaEbeanServerLifecycle ninjaEbeanServerLifecycle;
    
    private EbeanServer ebeanServer;
    
    private CasinoUserManager casinoUserManager;
    
   
    @Before
    public void setup() {
        
        injector = Guice.createInjector(new CasinoEbeanModule(), new AbstractModule() {
            
            @Override
            protected void configure() {
                bind(Logger.class).toProvider(LoggerProvider.class);
                
            }
        });
        
        //start ebeans server manually:
        ninjaEbeanServerLifecycle = injector.getInstance(
                NinjaEbeanServerLifecycle.class);
        
        ninjaEbeanServerLifecycle.startServer();
        
        ebeanServer = injector.getInstance(EbeanServer.class);
        casinoUserManager = injector.getInstance(CasinoUserManager.class);
        
    }
        
    @After
    public void tearDown() {
        
        ninjaEbeanServerLifecycle.stopServer();
    }
    
    
    @Test
    public void testCreateNewCasinoUser() {
        
        // this will create a new user:
        boolean hasUserBeenCreated = casinoUserManager.createNewCasinoUser(
                "email@example.com", "pwHash", "confirmationCode");
        
        // Make sure the user has been created
        assertTrue(hasUserBeenCreated);
        
        // Now we query the database and get the user with matching email
        User user = ebeanServer.find(User.class).where().eq("email", "email@example.com").findUnique();
            
        // Make sure we got the correct information and saving works:
        assertEquals("email@example.com", user.getEmail());
        assertEquals("pwHash", user.getPwHash());
        assertEquals("confirmationCode", user.getConfirmationCode());   
        
        // Call the method again. This may not succeed as the user (with same email) 
        // does already exist:
        hasUserBeenCreated = casinoUserManager.createNewCasinoUser(
                "email@example.com", "pwHash", "confirmationCode");
        
        // As stated above: This may not succeed:
        assertFalse(hasUserBeenCreated);
        
    }

}
