/**
 * Copyright (C) 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package models.casino;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

import javax.persistence.Entity;

@Entity
public class User {

    private String confirmationCode;

    private String recoverPasswordCode;

    private ArrayList<String> roles;

    private String email;

    private String pwHash;

    public String getPwHash() {
        return pwHash;
    }

    public void setPwHash(String pwHash) {
        this.pwHash = pwHash;
    }

    public String getConfirmationCode() {
        return confirmationCode;
    }

    public void setConfirmationCode(String confirmationCode) {
        this.confirmationCode = confirmationCode;
    }

    public String getRecoverPasswordCode() {
        return recoverPasswordCode;
    }

    public void setRecoverPasswordCode(String recoverPasswordCode) {
        this.recoverPasswordCode = recoverPasswordCode;
    }

    public User(String email, String passwordHash, String confirmationCode) {

        this.setEmail(email);
        this.pwHash = passwordHash;
        this.confirmationCode = confirmationCode;

        this.roles = new ArrayList<String>();
    }

    public boolean hasRole(String role) {

        HashSet<String> rolesSet = new HashSet<String>(getRoles());

        return rolesSet.contains(role);

    }

    public void addRole(String role) {

        HashSet<String> rolesSet = new HashSet<String>(getRoles());
        rolesSet.add(role);

        getRoles().clear();
        getRoles().addAll(new ArrayList<String>(rolesSet));

    }

    public void removeRole(String role) {

        HashSet<String> rolesSet = new HashSet<String>(getRoles());
        rolesSet.remove(role);

        getRoles().clear();
        getRoles().addAll(new ArrayList<String>(rolesSet));

    }

    private List<String> getRoles() {

        if (roles == null) {
            roles = new ArrayList<String>();
        }

        return roles;

    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

}