/**
 * Copyright (C) 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package casino;

import com.google.inject.ImplementedBy;

/**
 * If you use the standard User models distributed by Casino! 
 * you are getting all you need: Password management for a user,  role management and more.
 * 
 * But sometimes you need even more. 
 * 
 * Generate a Settings Entity right after a user is executed for instance.
 * 
 * The execute method let's you implement that functionality.
 *
 */
@ImplementedBy(AfterUserCreationHookThatDoesNothing.class)
public interface AfterUserCreationHook {

    /**
     * This method will be called by Casino when a user has been created successfully in
     * you database. 
     * 
     * Use cases include the generation of Settings for a user after he has been created.
     * 
     * @param email The email of the user (must be unique).
     */
    public void execute(String email);

}
