/**
 * Copyright (C) 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package casino;

import ninja.postoffice.Mail;
import ninja.postoffice.Postoffice;
import ninja.utils.NinjaProperties;

import com.google.inject.Inject;
import com.google.inject.Provider;
import com.google.inject.Singleton;

@Singleton
public class RegistrationMailer {

    private final Postoffice postoffice;
    private final Provider<Mail> mailProvider;
    
    private final String emailFrom;

    @Inject
    public RegistrationMailer(NinjaProperties ninjaProperties, Postoffice postoffice, Provider<Mail> mailProvider) {
        this.postoffice = postoffice;
        this.mailProvider = mailProvider;
        
        emailFrom = ninjaProperties.getOrDie(CasinoApplicationConfConstants.EMAIL_FROM);
    }

    public void confirmation(String email, String confirmationCode) throws Exception {
       
        Mail mail = mailProvider.get();   
        
        mail.setSubject("Registration confirmation");
        mail.setFrom(emailFrom);
        mail.addTo(email);
        
        String confirmationLink = String.format("/registration/confirm/%s", confirmationCode);
                
        String content = String.format("Hi, please visit %s to activate your account!", confirmationLink);
        mail.setBodyText(content);
        
        //and send the mail
        postoffice.send(mail);

    }

    public void lostPassword(String email, String recoverPasswordCode) {
        System.out.println("lostPassword");
        // // user.recoverPasswordCode = Registration.shortUUID();
        // // user.save();
        //
        // Map<String, Object> args = new HashMap<String, Object>();
        // args.put("code", recoverPasswordCode);
        // String confirmation_link = Router.getFullUrl(
        // "casino.Registration.lostPasswordNewPassword", args);
        // setSubject("Recover Password");
        //
        // addRecipient(email);
        //
        // String emailFrom = Play.configuration.getProperty(
        // CasinoApplicationConfConstants.EMAIL_FROM, "");
        //
        // if (emailFrom.equals("")) {
        //
        // throw new RuntimeException(
        // "casino.emailFrom not set in applications.conf. Doing nothing...");
        // } else {
        //
        // setFrom(emailFrom);
        //
        // send("casino/Registration/lostPasswordEmail", email,
        // confirmation_link);
        // }
    }

}
